l8web

package
v0.0.0-...-bf0348c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 17, 2026 License: Apache-2.0 Imports: 4 Imported by: 36

Documentation

Index

Constants

This section is empty.

Variables

Functions

This section is empty.

Types

type L8Empty

type L8Empty struct {
	// contains filtered or unexported fields
}

L8Empty is an empty message used as a placeholder for void requests/responses.

func (*L8Empty) Descriptor deprecated

func (*L8Empty) Descriptor() ([]byte, []int)

Deprecated: Use L8Empty.ProtoReflect.Descriptor instead.

func (*L8Empty) ProtoMessage

func (*L8Empty) ProtoMessage()

func (*L8Empty) ProtoReflect

func (x *L8Empty) ProtoReflect() protoreflect.Message

func (*L8Empty) Reset

func (x *L8Empty) Reset()

func (*L8Empty) String

func (x *L8Empty) String() string

type L8Plugin

type L8Plugin struct {

	// Plugin-specific configuration data (typically JSON or other serialized format)
	Data string `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

L8Plugin contains arbitrary plugin configuration data. Used by web service plugins for custom behavior.

func (*L8Plugin) Descriptor deprecated

func (*L8Plugin) Descriptor() ([]byte, []int)

Deprecated: Use L8Plugin.ProtoReflect.Descriptor instead.

func (*L8Plugin) GetData

func (x *L8Plugin) GetData() string

func (*L8Plugin) ProtoMessage

func (*L8Plugin) ProtoMessage()

func (*L8Plugin) ProtoReflect

func (x *L8Plugin) ProtoReflect() protoreflect.Message

func (*L8Plugin) Reset

func (x *L8Plugin) Reset()

func (*L8Plugin) String

func (x *L8Plugin) String() string

type L8WebService

type L8WebService struct {

	// Name of the backing Layer 8 service
	ServiceName string `protobuf:"bytes,1,opt,name=service_name,json=serviceName,proto3" json:"service_name,omitempty"`
	// Service area to route requests to
	ServiceArea int32 `protobuf:"varint,2,opt,name=service_area,json=serviceArea,proto3" json:"service_area,omitempty"`
	// Map of HTTP method (ordinal) to endpoint configuration
	Endpoints map[int32]*L8WebServiceEndpoint `` /* 160-byte string literal not displayed */
	// Plugin configuration for custom processing
	Plugin *L8Plugin `protobuf:"bytes,4,opt,name=plugin,proto3" json:"plugin,omitempty"`
	// Virtual network identifier for routing
	Vnet uint32 `protobuf:"varint,5,opt,name=vnet,proto3" json:"vnet,omitempty"`
	// contains filtered or unexported fields
}

L8WebService defines a web service configuration for exposing HTTP endpoints. Maps HTTP methods to service handlers and manages plugin data.

func (*L8WebService) Descriptor deprecated

func (*L8WebService) Descriptor() ([]byte, []int)

Deprecated: Use L8WebService.ProtoReflect.Descriptor instead.

func (*L8WebService) GetEndpoints

func (x *L8WebService) GetEndpoints() map[int32]*L8WebServiceEndpoint

func (*L8WebService) GetPlugin

func (x *L8WebService) GetPlugin() *L8Plugin

func (*L8WebService) GetServiceArea

func (x *L8WebService) GetServiceArea() int32

func (*L8WebService) GetServiceName

func (x *L8WebService) GetServiceName() string

func (*L8WebService) GetVnet

func (x *L8WebService) GetVnet() uint32

func (*L8WebService) ProtoMessage

func (*L8WebService) ProtoMessage()

func (*L8WebService) ProtoReflect

func (x *L8WebService) ProtoReflect() protoreflect.Message

func (*L8WebService) Reset

func (x *L8WebService) Reset()

func (*L8WebService) String

func (x *L8WebService) String() string

type L8WebServiceEndpoint

type L8WebServiceEndpoint struct {

	// Map of request body type to response type (fully qualified type names)
	Body2Response map[string]string `` /* 167-byte string literal not displayed */
	// Default/primary request body type when not explicitly specified
	PrimaryBody string `protobuf:"bytes,2,opt,name=primaryBody,proto3" json:"primaryBody,omitempty"`
	// contains filtered or unexported fields
}

L8WebServiceEndpoint configures the request/response mapping for an HTTP endpoint.

func (*L8WebServiceEndpoint) Descriptor deprecated

func (*L8WebServiceEndpoint) Descriptor() ([]byte, []int)

Deprecated: Use L8WebServiceEndpoint.ProtoReflect.Descriptor instead.

func (*L8WebServiceEndpoint) GetBody2Response

func (x *L8WebServiceEndpoint) GetBody2Response() map[string]string

func (*L8WebServiceEndpoint) GetPrimaryBody

func (x *L8WebServiceEndpoint) GetPrimaryBody() string

func (*L8WebServiceEndpoint) ProtoMessage

func (*L8WebServiceEndpoint) ProtoMessage()

func (*L8WebServiceEndpoint) ProtoReflect

func (x *L8WebServiceEndpoint) ProtoReflect() protoreflect.Message

func (*L8WebServiceEndpoint) Reset

func (x *L8WebServiceEndpoint) Reset()

func (*L8WebServiceEndpoint) String

func (x *L8WebServiceEndpoint) String() string

Jump to